==> mct_nightly-1.6.0.8112022.post448-py3-none-any.whl: model_compression_toolkit/core/pytorch/back2framework/quantization_wrapper/wrapper_quantize_config.py <==
# Copyright 2022 Sony Semiconductor Israel, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

class WrapperQuantizeConfig:
    """
    Configuration for how a layer should be quantized.
    """

    def __init__(self,
                 is_weight_quantized: bool,
                 is_activation_quantized: bool
                 ):
        """

        Args:
            is_weight_quantized: Whether weights quantization is enabled or not.
            is_activation_quantized: Whether activation quantization is enabled or not.
        """

        self.is_weight_quantized = is_weight_quantized
        self.is_activation_quantized = is_activation_quantized

    def get_weight_quantizers(self) -> list:
        """

        Returns: A List of quantizers for weights quantization.

        """
        raise NotImplemented


    def get_activation_quantizers(self) -> list:
        """

        Returns: A List of quantizers for activation quantization.

        """
        raise NotImplemented

==> mct_nightly-2.2.0.20241121.524-py3-none-any.whl: model_compression_toolkit/core/pytorch/back2framework/quantization_wrapper/wrapper_quantize_config.py <==
# Copyright 2022 Sony Semiconductor Israel, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

class WrapperQuantizeConfig:
    """
    Configuration for how a layer should be quantized.
    """

    def __init__(self,
                 is_weight_quantized: bool,
                 is_activation_quantized: bool
                 ):
        """

        Args:
            is_weight_quantized: Whether weights quantization is enabled or not.
            is_activation_quantized: Whether activation quantization is enabled or not.
        """

        self.is_weight_quantized = is_weight_quantized
        self.is_activation_quantized = is_activation_quantized

    def get_weight_quantizers(self) -> list:
        """

        Returns: A List of quantizers for weights quantization.

        """
        raise NotImplemented  # pragma: no cover

    def get_activation_quantizers(self) -> list:
        """

        Returns: A List of quantizers for activation quantization.

        """
        raise NotImplemented  # pragma: no cover
